Package cloud.commandframework.arguments.parser
package cloud.commandframework.arguments.parser
Parser classes used to parse
CommandArgument-
Interface SummaryInterfaceDescriptionArgumentParser<C,T>Parser that parses strings into values of a specific typeRegistry of
ArgumentParserthat allows these arguments to be referenced by aClass(or really, aTypeToken) or aStringkey -
Class SummaryClassDescriptionResult of the parsing done by a
ArgumentParserMappedArgumentParser<C,I,O>An argument parser which wraps another argument parser, converting the output type.Parser parameter used when retrieving parsers from theParserRegistryCommon parser parameters used when resolving types in theParserRegistryStandard implementation ofParserRegistry