Package cloud.commandframework.extra.confirmation


package cloud.commandframework.extra.confirmation
Confirmation system
  • Class Summary
    Class
    Description
    Manager for the command confirmation system that enables the ability to add "confirmation" requirements to commands, such that they need to be confirmed in order to be executed.