Package cloud.commandframework.keys
Interface CloudKeyHolder<T>
-
- Type Parameters:
T- The type of the key value.
- All Known Subinterfaces:
PredicatePermission<C>
- All Known Implementing Classes:
ArgumentPair,ArgumentTriplet,BooleanArgument,ByteArgument,CharArgument,CommandArgument,CompoundArgument,DoubleArgument,EnumArgument,FlagArgument,FloatArgument,IntegerArgument,LongArgument,ShortArgument,StaticArgument,StringArgument,StringArrayArgument,UUIDArgument
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@FunctionalInterface public interface CloudKeyHolder<T>Represents any object that holds aCloudKey- Since:
- 1.4.0
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description @NonNull CloudKey<T>getKey()Get the key that identifies this object.
-